###### 1. Import the dataset #######
# This imports the function `data_as_list_of_lists` from `data.py`
# This only works if `data.py` is in this folder
from data import data_header, data_as_list_of_lists

# Load the header and the dataset
pahrump_census_filename = "nvcensus-1920-pahrump.csv"
pahrump_census_columns = data_header(pahrump_census_filename)
pahrump_census = data_as_list_of_lists(pahrump_census_filename)

# Please confirm that your dataset is a list of lists
print(type(pahrump_census))
print(type(pahrump_census[0]))
print(type(pahrump_census[0][0]))

# Please print out the header, and then every record individually
print(pahrump_census_columns)
for row in pahrump_census:
    print(row)

# Do you understand what is in this dataset? Please describe!

"""
Some words describing the rows, columns, etc.
"""

###### 2. Counting people #######
# We want to know the number of people in Pahrump
n = 0
for row in pahrump_census:
    n += 1

population = n
# or just
population = len(pahrump_census)

print(f"The total population is {population}.")

##### 3. Adding people ######
# Add an unemployed 0-year-old white female named "ANNIE GOODWIN" to the data.
pahrump_census.append(
    ["1920", "PAHRUMP PRECINCT", "ANNIE", "GOODWIN", "0", "F", "W", "NONE"]
)

# Show that she has been added. Has the population increased?
print(pahrump_census[-1])

new_population = len(pahrump_census)
print(f"The total population is now {new_population}.")

##### 4. Labor force participation #####

# Get the number of employed individuals.
# To tell if they're employed, see if their
# occupation is not "NONE"

n_employed = 0
for row in pahrump_census:
    if row[7] != "NONE":
        n_employed += 1


# The labor force participation rate is simply
# the number of working individuals divided by
# the size of the population.

# What is the LFPR?
lfpr = n_employed / population
print(f"The LFPR is {lfpr:.2f}.")


###### 5. Subsetting ########

# We will create four subpopulations from the census data.
children = []
elderly = []
women = []
men = []
males = []
females = []

for row in pahrump_census:
    if row[5] == "M":
        males.append(row)
    else:
        females.append(row)

for row in pahrump_census:
    if int(row[4]) < 18:
        children.append(row)
    else:
        if row[5] == "M":
            men.append(row)
        else:
            women.append(row)
        if int(row[4]) >= 75:
            elderly.append(row)

n_children_employed = 0
n_men_employed = 0
n_women_employed = 0
n_elderly_employed = 0
n_males_employed = 0
n_females_employed = 0

for row in children:
    if row[7] != "NONE":
        n_children_employed += 1

for row in men:
    if row[7] != "NONE":
        n_men_employed += 1

for row in women:
    if row[7] != "NONE":
        n_women_employed += 1

for row in elderly:
    if row[7] != "NONE":
        n_elderly_employed += 1

for row in males:
    if row[7] != "NONE":
        n_males_employed += 1

for row in females:
    if row[7] != "NONE":
        n_females_employed += 1
# After populating these, what is the LFPR for each group?

# there was ambiguity about whether to calculate the LFPR
# for all men or all adult men (either was fine, but
# they're different)
children_lfpr = n_children_employed / len(children)
women_lfpr = n_women_employed / len(women)
men_lfpr = n_men_employed / len(men)
elderly_lfpr = n_elderly_employed / len(elderly)
females_lfpr = n_females_employed / len(females)
males_lfpr = n_males_employed / len(males)

print(
    f"The LFPR for children is {children_lfpr:.2f}.\n"
    f"The LFPR for working-age men is {men_lfpr:.2f}.\n"
    f"The LFPR for working-age women is {women_lfpr:.2f}.\n"
    f"The LFPR for the elderly is {elderly_lfpr:.2f}.\n"
    f"The LFPR for all males is {males_lfpr:.2f}.\n"
    f"The LFPR for all females is {females_lfpr:.2f}.\n"
)

# Do these numbers make sense?

"""
Children LFPR is problematic => 0 used as missing value.
"""

### Extra Exercises ###

### 1. Tax receipts ###
# Calculate the tax receipts from the town.
# PROFESSION          SALARY  TAX RECEIPTS
# ----------          ------   ------------
# MINER                 5000            240
# FARMER               12000           1150
# FARM LABORER          2600            104
# OTHER PROFESSION      3200            128
# NO PROFESSION            0              0

revenue = 0

for row in pahrump_census:
    if row[7] == "MINER":
        revenue += 240
    elif row[7] == "FARM LABORER":
        revenue += 104
    elif row[7] == "FARMER":
        revenue += 1150
    elif row[7] == "NONE":
        revenue += 0
        # better: continue
    else:
        revenue += 128

print(f"Total tax revenue is ${revenue}.")

### 2. Other towns ###

# Take a look at data.py. Modify it to create a census for another town, then
# reproduce the analysis done here on that town.
# To use data.py, you must download the full data file from:
# https://doi.org/10.7910/DVN/27218
